@@ -1,3 +1,5 @@
+#!/usr/bin/env bash
+
 # If a command fails, exit this script with an error code
 set -e
 
@@ -5,7 +7,7 @@ set -e
 # Compile Digraphs and install Digraphs lib
 if [ "$SUITE" != "lint" ]; then
   echo -e "\nCompiling the Digraphs package..."
-  cd $GAPROOT/pkg/digraphs
+  cd $HOME/gap/pkg/digraphs
   ./autogen.sh
   ./configure $PKG_FLAGS
   make
